// Copyright (C) 2017 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QTNFC_H
#define QTNFC_H

#include <QtCore/qglobal.h>
#include <QtNfc/qtnfcexports.h>

#endif // QTNFC_H
