// Copyright (C) 2017 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef QTBLUETOOTH_H
#define QTBLUETOOTH_H

#include <QtCore/qglobal.h>
#include <QtBluetooth/qtbluetooth-config.h> // for feature detection
#include <QtBluetooth/qtbluetoothexports.h>

#endif // QTBLUETOOTH_H
