/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -I QtCore/private/qglobal_p.h -p profilemanager1_p.h:profilemanager1.cpp org.bluez.ProfileManager1.xml
 *
 * qdbusxml2cpp is Copyright (C) 2022 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef PROFILEMANAGER1_P_H
#define PROFILEMANAGER1_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include <QtCore/private/qglobal_p.h>

/*
 * Proxy class for interface org.bluez.ProfileManager1
 */
class OrgBluezProfileManager1Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.bluez.ProfileManager1"; }

public:
    OrgBluezProfileManager1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgBluezProfileManager1Interface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> RegisterProfile(const QDBusObjectPath &profile, const QString &UUID, const QVariantMap &options)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(profile) << QVariant::fromValue(UUID) << QVariant::fromValue(options);
        return asyncCallWithArgumentList(QStringLiteral("RegisterProfile"), argumentList);
    }

    inline QDBusPendingReply<> UnregisterProfile(const QDBusObjectPath &profile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(profile);
        return asyncCallWithArgumentList(QStringLiteral("UnregisterProfile"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace bluez {
    using ProfileManager1 = ::OrgBluezProfileManager1Interface;
  }
}
#endif
